files
==================================================
**Module**: :mod:`espressodb.management.utilities.files`

.. currentmodule:: espressodb.management.utilities.files

.. autosummary::
   get_project_settings
   get_db_config
   ESPRESSO_DB_ROOT

------

.. automodule:: espressodb.management.utilities.files
    :members:
    :exclude-members: ESPRESSO_DB_ROOT

.. autodata:: ESPRESSO_DB_ROOT
   :annotation: = 'path/to/espressodb'
